# geogradev


[![image](https://img.shields.io/pypi/v/geogradev.svg)](https://pypi.python.org/pypi/geogradev)
[![image](https://img.shields.io/conda/vn/conda-forge/geogradev.svg)](https://anaconda.org/conda-forge/geogradev)


**A python package for geospatial analysis and mapping**


-   Free software: MIT License
-   Documentation: https://mercedes1996.github.io/geogradev
    

## Features

-   TODO
